@@ -70,6 +70,7 @@ def test_model(config: dict, fun_control: dict) -> Tuple[float, float]:
             dataset=fun_control["data_set"],
             data_full_train=fun_control["data_full_train"],
             data_test=fun_control["data_test"],
+            data_val=fun_control["data_val"],
             batch_size=config["batch_size"],
             num_workers=fun_control["num_workers"],
             test_size=fun_control["test_size"],
@@ -109,7 +110,8 @@ def test_model(config: dict, fun_control: dict) -> Tuple[float, float]:
     trainer.fit(model=model, datamodule=dm)
 
     # Load the last checkpoint
-    test_result = trainer.test(datamodule=dm, ckpt_path="last")
+    # test_result = trainer.test(datamodule=dm, ckpt_path="last")
+    test_result = trainer.test(datamodule=dm, ckpt_path="best")
     test_result = test_result[0]
     print(f"test_model result: {test_result}")
     return test_result["val_loss"], test_result["hp_metric"]
